```{.include}
README.md
```

# Specification

## External includes

Use the following in your markdown file to include any other markdown file:

````markdown
```{.include}
README.md
```
````

The path of the file is with respect to the working directory where `pandoc` is executed.

## Codeblocks

```
Multi line Code blocks are indented 4 spaces and

are formatted

appropriately with > and <.
```

Alternatively, you can use `vimdoc` as the language for the code block to write raw text that will be inserted into the final document.

For example, the following:

````
```vimdoc
You can use codeblocks that have language as `vimdoc` to write raw vimdoc.
```
````

will be rendered as below:

```vimdoc
You can use codeblocks that have language as `vimdoc` to write raw vimdoc.
```

# Title

The first line of the documentation that is generated will look something like this:

```
*panvimdoc.txt*    For VIM - Vi IMproved 8.1       Last change: 2021 August 11
```

# Heading

Main headings are numbered.

<!-- panvimdoc-ignore-start -->

```
==============================================================================
2. Heading                                                 *panvimdoc-heading*

Main headings are numbered.
```

<!-- panvimdoc-ignore-end -->

## Sub Heading 2

Sub headings are upper cased heading.

<!-- panvimdoc-ignore-start -->

```
SUB HEADING 2                                        *panvimdoc-sub-heading-2*

Sub headings are upper cased heading.
```

<!-- panvimdoc-ignore-end -->

Notice that both headings and subheadings have tags.

## Markdown Links

You can use markdown links in vimdoc. For example, see the [links](#links) section in the generated vim document.

The following markdown:

```markdown
You can link to the tags by using [sub heading 2](#sub-heading-2).
```

is converted to the following vimdoc:

```
You can link to the tags by using |projectName-sub-heading-2|.
```

This way, any links will work in markdown README on GitHub or on the web using anchors AND will work as tags and links in vimdoc.
The anchors are simply dropped in vimdoc inline.
The onus is on the documentation writer to choose the correct anchor for the appropriate Markdown link.

In vim doc tags are created when anchors to the internal document are used.
If the target is an external link, the link is populated in a separate autogenerated [links](#links) section.

If the external link is to the neovim documentation, an internal vim link is generated. See [cursorcolumn](https://neovim.io/doc/user/options.html#'cursorcolumn') or [`completeopt`](https://neovim.io/doc/user/options.html#'completeopt') as an example.
This is excluded from the links section.

Lastly, if the markdown text is a url, the link is not added to the links section and instead is placed inline.

## Mappings

Any markdown header of level 3 is a special header. It can be used to generate documentation of mappings.
All of the content in curly braces `{...}` that is part of the header is dropped and a tag is created.

For example, the level 3 heading and the contents of the section as follows:

```
### abc{xyz}

Docstring for abc {xyz}.
```

becomes the following vimdoc:

```
                                                               *projectName-abc*

abc{xyz}                               Docstring for abc {xyz}.
```

Notice that the tag `*projectName-abc` is generated for you:

Additionally, content in square brackets `[...]` is also dropped for creating the tag name.

The heading `### :[range]Command` becomes the tag `*projectName-:Command*`.

See following headings as examples:

### pv{motion}

Command that operates over {motion} moved.

The following vimdoc mapping is generated:

```
                                                                *projectName-pv*

pv{motion}                             Command that operates over {motion}
                                       moved.

```

### pvd

Command that takes [count] lines.

The following vimdoc mapping is generated:

```
                                                               *projectName-pvd*

pvd                                    Command that takes [count] lines.

```

### :[range]CommandName {doc=CommandName}

Command that operates over [range].

The following vimdoc mapping is generated:

```

                                        *projectName-:CommandName* *CommandName*

:[range]CommandName                    Command that operates over [range].
```

You can use `{doc=AdditionalTag}` to generate one additional tag for each header.

### {Visual}pv

Command that operates over highlighted lines.

The following vimdoc mapping is generated:

```
                                                                *panvimdoc-pv*

{Visual}pv                             Command that operates over highlighted
                                       lines.
```

## Table

Support for markdown tables is also available:

<!-- prettier-ignore-start -->

<!-- panvimdoc-ignore-start -->

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

Table:  Demonstration of simple table syntax.

<!-- prettier-ignore-end -->

<!-- panvimdoc-ignore-end -->

```
│Right│Left│Center│Default│
│   12│12  │  12  │12     │
│  123│123 │ 123  │123    │
│    1│1   │  1   │1      │
```

## Markdown only content

Content that needs to be presented only in Markdown can be inside `panvimdoc-ignore-{start/end}` blocks:

```
<!-- panvimdoc-ignore-start -->

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

Table:  Demonstration of simple table syntax.

<!-- panvimdoc-ignore-end -->
```

<!-- prettier-ignore-start -->

<!-- panvimdoc-ignore-start -->

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

Table:  Demonstration of simple table syntax.

<!-- prettier-ignore-end -->

<!-- panvimdoc-ignore-end -->
